pub fn parse_with_backend<B: ParseBackend>(
input: &str,
file_id: FileId,
backend: &B,
opts: &ParseOptions,
) -> ParseResultExpand description
Parse a single file with the given backend and options.
pub fn parse_with_backend<B: ParseBackend>(
input: &str,
file_id: FileId,
backend: &B,
opts: &ParseOptions,
) -> ParseResultParse a single file with the given backend and options.