pub fn unsupported_dialect_feature_diagnostic(
feature: OracleFeature,
target: OracleTargetVersion,
span: Option<Span>,
) -> Option<Diagnostic>Expand description
Build a Diagnostic reporting that feature is not available on the
parse_options.oracle_version target.
Returns None when the feature is supported on the target — callers can
use this as both a check and a builder.